@@ -1,9 +1,10 @@
 from .normalise import Normalise
+from .validate import Validate
 
 # Metadata
 __doc__ = "Package to help with normalizing data needed for the platform!"
 # Github CI/CD greps for the version number.
-__version__ = "1.3"
+__version__ = "1.3.1"
 __author__ = "Michiel Masselink"
 __email__ = "m.masselink@yahoo.com"
 __license__ = "MIT"
